@@ -27,9 +27,8 @@ betweenSubjectMPT <- function(model1, model2,
 
   ################ check input
 
-  if(#class(model1) != class(model2) ||
-     ! class(model1) %in% c("betaMPT","traitMPT", "simpleMPT") ||
-     ! class(model2) %in% c("betaMPT","traitMPT", "simpleMPT"))
+  if(! inherits(model1, c("betaMPT","traitMPT", "simpleMPT")) ||
+     ! inherits(model2, c("betaMPT","traitMPT", "simpleMPT")))
     stop("The two models 'model1' and 'model2' must be (hierarchical) MPT models",
          "\n  of the class (both traitMPT / betaMPT / simpleMPT).")
   if(missing(par1) || length(par1) != 1 || !is.character(par1))
