@@ -61,10 +61,47 @@ covStringPredictor <- function(covTable, S, predFactorLevels=NULL, IVprec="dgamm
     }
     modelString <- paste0(modelString, "\n}\n")
 
+    # parameter labels in JAGS:
+    covPars <- covTable$covPar
+
+
+
+    ############################### standardization of regression slopes (--> to get correlations)
+
+    if(!is.null(covTable)){
+      modelString <- paste0(modelString,
+                            "\n### standardization of regression slopes",
+                            "(only for continuous predictors)\n\n")
+      select_cont <- which(covTable$predType == "c")
+      slope_std <- gsub("slope_", "slope_std_", covTable$covPar[select_cont], fixed = TRUE)
+      covPars <- c(covPars, slope_std)
+      for(pp in seq_along(slope_std)){
+
+        s <- covTable$theta[select_cont[pp]]
+        k <- covTable$covIdx[select_cont[pp]]
+
+        # for partially standardized slopes (z-standardized predictors):
+        # slope_std[pp] <- slope[pp] / sqrt(slope[pp]^2 + sigma[s]^2)
+
+        # for unstandardized predictors:
+        # slope_std[pp] <- slope[pp] * sqrt(covVar[k]) / sqrt(slope[pp]^2 + covVar[k] + sigma[s]^2)
+
+        modelString <- paste0(modelString,
+                              slope_std[pp], " <- ",
+                              covTable$covPar[select_cont[pp]], " * sqrt(covVar[", k, "]) / ",
+                              "sqrt(",
+                              "pow(", covTable$covPar[select_cont[pp]], ",2)",
+                              "* covVar[", k, "]",
+                              " + Sigma[", s, ",", s, "]",
+                              ") \n"
+        )
+      }
+      modelString <- paste0(modelString, "\n")
+    }
+
 
     ############################### HYPERPRIORS     ###############################
 
-    covPars <- covTable$covPar
     X_list <- list()  # list with design matrices for fixed effects)
 
     # inverse-g prior for Zellner-Siow priors (contin. predictors)
